/*
 * The contents of this file are subject to the Mozilla Public
 * License Version 1.1 (the "License") you may not use this file
 * except in compliance with the License. You may obtain a copy of
 * the License at http://www.mozilla.org/MPL/
 * 
 * Software distributed under the License is distributed on an "AS
 * IS" basis, WITHOUT WARRANTY OF ANY KIND, either express or
 * implied. See the License for the specific language governing
 * rights and limitations under the License.
 * 
 * The Original Code in this file was released on September 25, 2004
 * 
 * Unless otherwise stated, the Initial Developer of the
 * Original Code is David Perry.  Portions created by David Perry are
 * Copyright (C) 2002 David Perry.  All rights reserved.
 * 
 * Contributor(s):
 *   David Perry <d.perry@utoronto.ca> (Original Author)
 *
 * Alternatively, the contents of this file may be used under the
 * terms of the GNU General Public License Version 2 or later (the
 * "GPL"), in which case the provisions of the GPL are applicable
 * instead of those above.  If you wish to allow use of your
 * version of this file only under the terms of the GPL and not to
 * allow others to use your version of this file under the MPL,
 * indicate your decision by deleting the provisions above and
 * replace them with the notice and other provisions required by
 * the GPL.  If you do not delete the provisions above, a recipient
 * may use your version of this file under either the MPL or the
 * GPL.
 */

/*
 * ClipboardSaver
 * --------------
 *
 * Some of the selection manipulation done in autoRewrap() can destroy
 * the X11 selection clipboard.  This saves and restores it.
 */

function auwrClipboardSaver() {
    this.dataStack = new Array();
    this.clipBoard = Components.classes["@mozilla.org/widget/clipboard;1"]
        .getService(Components.interfaces.nsIClipboard);
    this.needed = this.clipBoard.supportsSelectionClipboard();
}

auwrClipboardSaver.prototype = {
    save: function()
    {
        if( !this.needed ) return;
        try
        {
            var transferable = Components.classes["@mozilla.org/widget/transferable;1"]
                .createInstance(Components.interfaces.nsITransferable);
            transferable.addDataFlavor("text/unicode");
            this.clipBoard.getData(transferable, this.clipBoard.kSelectionClipboard);
            var flavour = {};
            var data = {};
            var length = {};
            transferable.getAnyTransferData(flavour, data, length);
            this.dataStack.push(data);
        }
        catch(ex) { }
    },
    restore: function()
    {
        if( !this.needed ) return;
        try
        {
            var data = this.dataStack.pop();
            var pasteClipboard = Components.classes["@mozilla.org/widget/clipboardhelper;1"]
                .getService(Components.interfaces.nsIClipboardHelper);
            data = data.value.QueryInterface(Components.interfaces.nsISupportsString).data;
            pasteClipboard.copyStringToClipboard(data, this.clipBoard.kSelectionClipboard);
        }
        catch(ex) { }
    }
};

/*
 * Prefs
 * -----
 *
 * Object to read (and eventually write) autorewrap prefs.
 */

function auwrPrefs() {
    this.prefObj = Components.classes[ "@mozilla.org/preferences-service;1" ]
                    .getService( Components.interfaces.nsIPrefBranch );
    this.prefBranch = "extensions.autorewrap.";
}

auwrPrefs.prototype = {
    getInt: function(prefName)
    {
        try
        {
            return this.prefObj.getIntPref(this.prefBranch+prefName);
        }
        catch(ex)
        {
            return null;
        }
    },
    getBool: function(prefName)
    {
        try
        {
            return this.prefObj.getBoolPref(this.prefBranch+prefName);
        }
        catch(ex)
        {
            return null;
        }
    },
    getChar: function(prefName)
    {
        try
        {
            return this.prefObj.getCharPref(this.prefBranch+prefName);
        }
        catch(ex)
        {
            return null;
        }
    },
};

/* EOF */
